<?php
/**
 * SyLȥƥץ졼
 *
 * ŬѹƻѤƤ
 */
class Index
{
    var $start_string;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function Index()
    {
    }

    /**
     * å
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȴ֥
     */
    function execute(&$data, &$context)
    {
        $this->start_string = 'Hello SyL!';
    }
}

?>
